@@ -149,7 +149,8 @@ sub DEFAULT_PROFILES {{
     # *does* want to edit, and manually sets allow_edit to true, the default editor
     # be a sane choice (hex) which will match the default renderer.
     editor     => { xtype => 'ra-hexfield', grow => \1 },
-    allow_edit => \0
+    allow_edit => \0,
+    broad_data_type => 'integer'
   },
   html => {
     width => 200,
@@ -288,6 +289,24 @@ sub DEFAULT_PROFILES {{
 
 }};
 
+our %NO_ALLOW_ADD_PROFILES = ();
+our %NO_ALLOW_EDIT_PROFILES = ();
+{
+  my $Defs = &DEFAULT_PROFILES;
+  for my $prof (keys %$Defs) {
+    my $p = $Defs->{$prof};
+    my ($a,$e) = ($p->{allow_add},$p->{allow_edit});
+    if(exists $p->{allow_add}) {
+      $a = $$a if (ref($a));
+      $NO_ALLOW_ADD_PROFILES{$prof} = 1 if ("$a" eq '0'); 
+    }
+    if(exists $p->{allow_edit}) {
+      $e = $$e if (ref($e));
+      $NO_ALLOW_EDIT_PROFILES{$prof} = 1 if ("$e" eq '0'); 
+    }
+  }
+}
+
 
 our $SKIP_BASE = 0;
 
