@@ -6,19 +6,25 @@ use Pod::Usage;
 
 use RapidApp::Helper;
 
+my $bootstrap_cmd = join(' ',(reverse split(/\//,$0))[0],@ARGV);
+
 my $force    = 0;
 my $help     = 0;
 my $makefile = 0;
 my $scripts  = 0;
+my $dir;
 
 my $helpers;
 
+# We no longer support "upgrading" existing apps like catalyst.pl
+# -- no longer accept those options from the command line
 GetOptions(
     'help|?'      => \$help,
-    'force|nonew' => \$force,
-    'makefile'    => \$makefile,
-    'scripts'     => \$scripts,
-    'helpers=s'   => \$helpers
+    #'force|nonew' => \$force,
+    #'makefile'    => \$makefile,
+    #'scripts'     => \$scripts,
+    'helpers=s'   => \$helpers,
+    'dir=s'       => \$dir
 );
 
 my $name = shift @ARGV;
@@ -39,13 +45,23 @@ sub _traits_list {
   } @list;
 }
 
+# --
+# Special default --dir for rapi/psgi
+# If we're being called from within the environment of the rapi/psgi docker image,
+# use the /opt/app directory as the default app target dir because it is the most
+# common-sense default for this scenario. See the rapi/psgi docs for more info
+$dir = "/opt/app" if($ENV{RAPI_PSGI_DOCKERIZED} && !$dir);
+# --
+
 my $helper = RapidApp::Helper->new_with_traits({
     '.newfiles' => !$force,
     'makefile'  => $makefile,
     'scripts'   => $scripts,
     'traits'    => [&_traits_list],
     name        => $name,
-    extra_args  => \@extra_args
+    ( $dir ? ('dir' => $dir) : () ),
+    extra_args  => \@extra_args,
+    bootstrap_cmd => $bootstrap_cmd
 });
 # Pass $ARGV[0] for compatibility with old ::Devel
 pod2usage(1) unless $helper->mk_app( $name );
@@ -62,15 +78,11 @@ rapidapp.pl - Bootstrap a RapidApp/Catalyst application
 
  rapidapp.pl [options] application-name [--] [extra options]
 
- 'rapidapp.pl' creates a skeleton for a new application, and allows you to
- upgrade the skeleton of your old application.
+ 'rapidapp.pl' creates a skeleton for a new RapidApp application
 
  Options:
-   -force      don't create a .new file where a file to be created exists
-   -help       display this help and exit
-   -makefile   only update Makefile.PL
-   -scripts    only update helper scripts
-
+  --help      display this help and exit
+  --dir       optional custom target directory (must be empty or not exist)
   --helpers   comma-separated list of helper traits (RapidApp::Helper::Traits::*)
 
  Extra Options:
